@@ -67,4 +67,10 @@ class ImageUtils:
     """
     @staticmethod
     def normalize(image_ndarray,max_value=255,dtype=np.uint8) -> np.ndarray:
-        return (image_ndarray*max_value/np.max(image_ndarray)).astype(dtype)
+        temp_image = image_ndarray-np.min(image_ndarray)
+        return (((temp_image)/np.max(temp_image))*max_value).astype(dtype)
+    
+    
+    # @staticmethod
+    # def clean_by_slice(image_ndarray:np.ndarray, leave_percentage:float)->np.ndarray:
+    #     sum_values
